#!/bin/sh
# SPDX-License-Identifier: BSD-2-Clause
# SPDX-FileCopyrightText: © 2018 Mopi
# SPDX-FileCopyrightText: © 2020 Fabien Givors <captnfab@debian-facile.org>
# SPDX-FileCopyrightText: © 2024 Antoine Le Gonidec <vv221@dotslashplay.it>
set -o errexit

###
# Myst 2: Riven
###

script_version=20240503.2

PLAYIT_COMPATIBILITY_LEVEL='2.29'

GAME_ID='myst-2-riven'
GAME_NAME='Riven: The Sequel to Myst'

ARCHIVE_BASE_1_NAME='setup_riven_-_the_sequel_to_myst_1.2_svm_no_launcher_(55114).exe'
ARCHIVE_BASE_1_MD5='879b8aaa724f4f422661634186ee2534'
ARCHIVE_BASE_1_TYPE='innosetup'
ARCHIVE_BASE_1_PART1_NAME='setup_riven_-_the_sequel_to_myst_1.2_svm_no_launcher_(55114)-1.bin'
ARCHIVE_BASE_1_PART1_MD5='dd91f1256d819d6f26d9d0bcaa81548f'
ARCHIVE_BASE_1_PART2_NAME='setup_riven_-_the_sequel_to_myst_1.2_svm_no_launcher_(55114)-2.bin'
ARCHIVE_BASE_1_PART2_MD5='2d03d82b784666472e1a3f436ed20924'
ARCHIVE_BASE_1_SIZE='6947081'
ARCHIVE_BASE_1_VERSION='1.2-gog55114'
ARCHIVE_BASE_1_URL='https://www.gog.com/game/riven_the_sequel_to_myst'

ARCHIVE_BASE_0_NAME='setup_riven_-_the_sequel_to_myst_1.2_svm_update3_(22594).exe'
ARCHIVE_BASE_0_MD5='0520fac1f2ae966aa5c490850b51930f'
ARCHIVE_BASE_0_TYPE='innosetup'
ARCHIVE_BASE_0_PART1_NAME='setup_riven_-_the_sequel_to_myst_1.2_svm_update3_(22594)-1.bin'
ARCHIVE_BASE_0_PART1_MD5='4ee339ad50203020e717a78ff95bb590'
ARCHIVE_BASE_0_PART2_NAME='setup_riven_-_the_sequel_to_myst_1.2_svm_update3_(22594)-2.bin'
ARCHIVE_BASE_0_PART2_MD5='2ff2d7d25f2e8c2995c17d8b122d672c'
ARCHIVE_BASE_0_SIZE='6954413'
ARCHIVE_BASE_0_VERSION='1.2-gog22594'

CONTENT_PATH_DEFAULT='.'
## TODO: System-provided fonts should be used instead, ScummVM expects to find them in the game directory.
CONTENT_FONTS_DATA_FILES='
freesans.ttf
mplus-2c-regular.ttf'
CONTENT_GAME_DATA_FILES='
riven.exe
a_data.mhk
b_data.mhk
b2_data.mhk
g_data.mhk
j_data1.mhk
j_data2.mhk
o_data.mhk
p_data.mhk
r_data.mhk
t_data1.mhk
t_data2.mhk
a_sounds.mhk
b_sounds.mhk
g_sounds.mhk
j_sounds.mhk
o_sounds.mhk
p_sounds.mhk
r_sounds.mhk
t_sounds.mhk
extras.mhk'
## The following localization files must be included, or ScummVM fails to detect the correct game version.
CONTENT_GAME0_DATA_FILES='
a_data_french.mhk
a_data_german.mhk
a_data_italian.mhk
a_data_japanese.mhk
a_data_polish.mhk
a_data_russian.mhk
a_data_spanish.mhk'
CONTENT_GAME_BIN_FR_FILES='
b_data_french.mhk
j_data_french.mhk
o_data_french.mhk
p_data_french.mhk
r_data_french.mhk
t_data_french.mhk'
CONTENT_DOC_DATA_FILES='
manual.pdf
readme.txt'

APP_MAIN_TYPE='scummvm'
APP_MAIN_SCUMMID='mohawk:riven'
APP_MAIN_ICON='app/goggame-1207658819.ico'
APP_MAIN_OPTIONS_BIN_EN='--language=en'
APP_MAIN_OPTIONS_BIN_FR='--language=fr'

PACKAGES_LIST='
PKG_BIN_EN
PKG_BIN_FR
PKG_DATA'

PKG_BIN_ID="$GAME_ID"
PKG_BIN_EN_ID="${PKG_BIN_ID}-en"
PKG_BIN_FR_ID="${PKG_BIN_ID}-fr"
PKG_BIN_PROVIDES="
$PKG_BIN_ID"
PKG_BIN_EN_PROVIDES="$PKG_BIN_PROVIDES"
PKG_BIN_FR_PROVIDES="$PKG_BIN_PROVIDES"
PKG_BIN_EN_DESCRIPTION='English localization'
PKG_BIN_EN_DESCRIPTION='French localization'

PKG_DATA_ID="${GAME_ID}-data"
PKG_DATA_DESCRIPTION='Common data'
PKG_BIN_DEPS="${PKG_BIN_DEPS:-} $PKG_DATA_ID"
PKG_BIN_EN_DEPS="$PKG_BIN_DEPS"
PKG_BIN_FR_DEPS="$PKG_BIN_DEPS"

# Load common functions

PLAYIT_LIB_PATHS="
$PWD
${XDG_DATA_HOME:="${HOME}/.local/share"}/play.it
/usr/local/share/games/play.it
/usr/local/share/play.it
/usr/share/games/play.it
/usr/share/play.it"

if [ -z "$PLAYIT_LIB2" ]; then
	for playit_lib_path in $PLAYIT_LIB_PATHS; do
		if [ -e "${playit_lib_path}/libplayit2.sh" ]; then
			PLAYIT_LIB2="${playit_lib_path}/libplayit2.sh"
			break
		fi
	done
fi
if [ -z "$PLAYIT_LIB2" ]; then
	printf '\n\033[1;31mError:\033[0m\n'
	printf 'libplayit2.sh not found.\n'
	exit 1
fi
. "$PLAYIT_LIB2"

# Extract game data

archive_extraction_default

# Include game data

content_inclusion_icons 'PKG_DATA'
content_inclusion_default

## Link the fonts in the hardcoded path the game engine expects.
fonts_source=$(path_fonts_ttf)
fonts_destination="$(package_path 'PKG_DATA')$(path_game_data)"
mkdir --parents "$fonts_destination"
for font_file in \
	'freesans.ttf' \
	'mplus-2c-regular.ttf'
do
	ln --symbolic "${fonts_source}/${font_file}" "$fonts_destination"
done

# Write launchers

launchers_generation 'PKG_BIN_EN'
launchers_generation 'PKG_BIN_FR'

# Build packages

packages_generation
case "${LANG%_*}" in
	('fr')
		lang_string='version %s :'
		lang_en='anglaise'
		lang_fr='française'
	;;
	('en'|*)
		lang_string='%s version:'
		lang_en='English'
		lang_fr='French'
	;;
esac
printf '\n'
printf "$lang_string" "$lang_en"
print_instructions 'PKG_DATA' 'PKG_BIN_EN'
printf "$lang_string" "$lang_fr"
print_instructions 'PKG_DATA' 'PKG_BIN_FR'

# Clean up

rm --recursive "$PLAYIT_WORKDIR"

exit 0
