#!/bin/sh
# SPDX-License-Identifier: BSD-2-Clause
# SPDX-FileCopyrightText: © 2024 Antoine Le Gonidec <vv221@dotslashplay.it>
set -o errexit

###
# Myst 3: Exile
###

script_version=20240531.1

PLAYIT_COMPATIBILITY_LEVEL='2.29'

GAME_ID='myst-3-exile'
GAME_NAME='Myst Ⅲ: Exile'

ARCHIVE_BASE_0_NAME='setup_myst_3_exile_1.27_rvm_(21807).exe'
ARCHIVE_BASE_0_MD5='e2b8e962326b8802009d3e30b9e4c8ff'
ARCHIVE_BASE_0_TYPE='innosetup'
ARCHIVE_BASE_0_PART1_NAME='setup_myst_3_exile_1.27_rvm_(21807)-1.bin'
ARCHIVE_BASE_0_PART1_MD5='c69e2780274f2830ab210d230889e5bb'
ARCHIVE_BASE_0_SIZE='2422163'
ARCHIVE_BASE_0_VERSION='1.27-gog21807'
ARCHIVE_BASE_0_URL='https://www.gog.com/game/myst_3_exile'

CONTENT_PATH_DEFAULT='.'
CONTENT_GAME_MAIN_FILES='
data
m3data'
CONTENT_DOC_MAIN_FILES='
manual.pdf'

APP_MAIN_SCUMMID='myst3:myst3'
APP_MAIN_ICON='app/goggame-1766899243.ico'

# Load common functions

PLAYIT_LIB_PATHS="
$PWD
${XDG_DATA_HOME:="${HOME}/.local/share"}/play.it
/usr/local/share/games/play.it
/usr/local/share/play.it
/usr/share/games/play.it
/usr/share/play.it"

if [ -z "$PLAYIT_LIB2" ]; then
	for playit_lib_path in $PLAYIT_LIB_PATHS; do
		if [ -e "${playit_lib_path}/libplayit2.sh" ]; then
			PLAYIT_LIB2="${playit_lib_path}/libplayit2.sh"
			break
		fi
	done
fi
if [ -z "$PLAYIT_LIB2" ]; then
	printf '\n\033[1;31mError:\033[0m\n'
	printf 'libplayit2.sh not found.\n'
	exit 1
fi
. "$PLAYIT_LIB2"

# Extract game data

archive_extraction_default

# Include game data

content_inclusion_icons
content_inclusion_default

# Write launchers

launchers_generation

# Build packages

packages_generation
print_instructions

# Clean up

rm --recursive "$PLAYIT_WORKDIR"

exit 0
